@@ -9,9 +9,12 @@ class Tests(unittest.TestCase):
     def setUp(self):
         pass
 
-    # Ensure each parsed problem only contains one problem (that one
-    # problem does not "bleed" into another one)
+
     def test_problem_format(self):
+        """
+        Ensure each parsed problem only contains one problem (that one problem
+        does not "bleed" into the next one due to an issue with line breaks)
+        """
         for problem in range(1, euler.TOTAL_PROBLEMS + 1):
             problemText = euler.get_problem(problem)
 
@@ -20,8 +23,9 @@ class Tests(unittest.TestCase):
             self.assertFalse('========='in problemText, msg=msg)
             self.assertFalse('\n\n\n' in problemText, msg=msg)
 
-    # Check that problem #1 returns the correct problem text
+
     def test_expected_problem(self):
+        """Check that problem #1 returns the correct problem text"""
         problemOne = textwrap.dedent(
             """
             If we list all the natural numbers below 10 that are multiples of 3 or 5,
@@ -33,9 +37,11 @@ class Tests(unittest.TestCase):
 
         self.assertEqual(problemOne[1:], euler.get_problem(1))
 
-    # Check that filenames are being formatted correctly
+
     def test_filename_format(self):
+        """Check that filenames are being formatted correctly"""
         self.assertEqual(euler.get_filename(1), "001.py")
+        self.assertEqual(euler.get_filename(10), "010.py")
         self.assertEqual(euler.get_filename(100), "100.py")
 
         self.assertRaises(ValueError, euler.get_filename, "string")
